==> v1.6.0.tar.gz: zyos_go_order_relate_rule/svc/small_public_platoon_relate_commission.go <==
package svc

import (
	"code.fnuoos.com/go_rely_warehouse/zyos_go_order_relate_rule.git/db"
	"code.fnuoos.com/go_rely_warehouse/zyos_go_order_relate_rule.git/md"
	zhios_order_relate_utils "code.fnuoos.com/go_rely_warehouse/zyos_go_order_relate_rule.git/utils"
	zhios_order_relate_logx "code.fnuoos.com/go_rely_warehouse/zyos_go_order_relate_rule.git/utils/logx"
	"encoding/json"
	"errors"
	"fmt"
	"strconv"
	"strings"
	"xorm.io/xorm"
)

// 批量分佣 订单显示
func BatchSmallGetPublicPlatoonRelateCommission(engine *xorm.Engine, masterId string, PublicPlatoonRelateCommissionReqList []*md.SmallPublicPlatoonRelateCommissionReq) (map[string]*md.SmallPublicPlatoonRelateCommissionResp, error) {
	var resp = make(map[string]*md.SmallPublicPlatoonRelateCommissionResp)
	//userPublicPlatoonSetting, err := db.UserPublicPlatoonSettingGetOneByParams(engine, map[string]interface{}{
	//	"key":   "is_open",
	//	"value": 1,
	//})
	//if err != nil {
	//	return nil, err
	//}
	for _, param := range PublicPlatoonRelateCommissionReqList {
		// 根据供应商
		rewardOpt, err := db.DbsPlanRewardByPvd(engine, param.Pvd)
		if err != nil {
			return nil, err
		}
		if rewardOpt == nil {
			return nil, zhios_order_relate_logx.Warn("找不到方案记录")
		}
		if rewardOpt.State == 0 {
			return nil, zhios_order_relate_logx.Warn("抽成方案未开启")
		}
		if rewardOpt.PlanCommissionId == 0 {
			return nil, zhios_order_relate_logx.Warn("抽成方案未设置佣金方案id")
		}
		fmt.Println("抽成设置:", zhios_order_relate_utils.SerializeStr(rewardOpt))
		fmt.Println("commission id:", rewardOpt.PlanCommissionId)

		//TODO::计算共富收益
		commissionOpt, err := db.DbsPlanCommissionById(engine, rewardOpt.PlanCommissionId)
		if err != nil || commissionOpt == nil || commissionOpt.Id == 0 {
			return nil, err
		}
		var subsidyTmp = make(map[string]*md.LvGrade)
		var tmp map[string]*md.LvGrade
		if err := json.Unmarshal([]byte(commissionOpt.Data), &tmp); err != nil {
			return nil, zhios_order_relate_logx.Warn(fmt.Sprintf("%s:分佣方案数据设置错误", masterId))
		}
		for _, v := range tmp {
			subsidyTmp[zhios_order_relate_utils.IntToStr(v.Lv)] = v
		}
		lvGrade := subsidyTmp[param.UserLevel]
		var directPush = make(map[string]string)
		var selfRateList = make(map[string]string)
		var commonWealthSystem = make(map[string]string)
		for _, coinId := range lvGrade.ReturnType {
			selfRateList[coinId] = zhios_order_relate_utils.Float64ToStr(zhios_order_relate_utils.StrToFloat64(lvGrade.SelfRateList[coinId]) * zhios_order_relate_utils.StrToFloat64(param.PendingAmount) / 100)
			commonWealthSystem[coinId] = zhios_order_relate_utils.Float64ToStr(zhios_order_relate_utils.StrToFloat64(lvGrade.CommonWealthSystem[coinId]) * zhios_order_relate_utils.StrToFloat64(param.PendingAmount) / 100)
			directPush[coinId] = zhios_order_relate_utils.Float64ToStr(zhios_order_relate_utils.StrToFloat64(lvGrade.DirectPush[coinId]) * zhios_order_relate_utils.StrToFloat64(param.PendingAmount))
		}

		//TODO::本次消费产生的共富收益给到谁
		var nowBenefitUid string
		userPublicPlatoonRelation, err := db.UserPublicPlatoonRelationGetOneByParams(engine, map[string]interface{}{
			"key":   "uid",
			"value": param.Uid,
		})
		if err != nil {
			return nil, err
		}
		if userPublicPlatoonRelation == nil {
			return nil, errors.New("未查询到公排关系记录")
		}
		if userPublicPlatoonRelation.FatherUid == "" {
			//TODO::原始创始人
			nowBenefitUid = ""
		} else {
			fatherPositions := strings.Split(userPublicPlatoonRelation.FatherUid, "-")
			var fatherPosition string
			userPublicPlatoonRelation.ReturnCommissionNum++

			remainder1 := (userPublicPlatoonRelation.ReturnCommissionNum) % len(fatherPositions)
			if remainder1 == 0 {
				fatherPosition = fatherPositions[len(fatherPositions)-1]
			} else {
				fatherPosition = fatherPositions[remainder1-1]
			}

			nowBenefitUsers, err := db.UserPublicPlatoonRelationGetOneByParams(engine, map[string]interface{}{
				"key":   "position",
				"value": fatherPosition,
			})
			if err != nil {
				return nil, err
			}
			if nowBenefitUsers == nil {
				return nil, errors.New("未查询到父级公排关系记录")
			}
			nowBenefitUid = zhios_order_relate_utils.AnyToString(nowBenefitUsers.Uid)

			//TODO::更新 公排关系记录 中 `return_commission_num`
			affected, err := db.UserPublicPlatoonRelationUpdate(engine.NewSession(), userPublicPlatoonRelation.Id, userPublicPlatoonRelation, "return_commission_num")
			if err != nil {
				return nil, err
			}
			if affected == 0 {
				return nil, errors.New("更新公排关系记录失败")
			}
		}

		resp[param.Oid] = &md.SmallPublicPlatoonRelateCommissionResp{
			Uid:                    param.Uid,
			CommonWealthBenefitUid: nowBenefitUid,
			DirectPushBenefitUid:   strconv.Itoa(userPublicPlatoonRelation.RecommendUid),
			PendingAmount:          param.PendingAmount,
			Oid:                    param.Oid,
			SelfRateList:           selfRateList,
			CommonWealthSystem:     commonWealthSystem,
			DirectPush:             directPush,
		}
	}
	return resp, nil
}

==> v1.8.4.tar.gz: zyos_go_order_relate_rule/svc/small_public_platoon_relate_commission.go <==
package svc

import (
	"code.fnuoos.com/go_rely_warehouse/zyos_go_order_relate_rule.git/db"
	"code.fnuoos.com/go_rely_warehouse/zyos_go_order_relate_rule.git/md"
	zhios_order_relate_utils "code.fnuoos.com/go_rely_warehouse/zyos_go_order_relate_rule.git/utils"
	zhios_order_relate_logx "code.fnuoos.com/go_rely_warehouse/zyos_go_order_relate_rule.git/utils/logx"
	"encoding/json"
	"errors"
	"fmt"
	"strconv"
	"strings"
	"xorm.io/xorm"
)

// 批量分佣 订单显示
func BatchSmallGetPublicPlatoonRelateCommission(engine *xorm.Engine, masterId string, PublicPlatoonRelateCommissionReqList []*md.SmallPublicPlatoonRelateCommissionReq) (map[string]*md.SmallPublicPlatoonRelateCommissionResp, error) {
	var resp = make(map[string]*md.SmallPublicPlatoonRelateCommissionResp)
	for _, param := range PublicPlatoonRelateCommissionReqList {
		// 根据供应商
		rewardOpt, err := db.DbsPlanRewardByPvd(engine, param.Pvd)
		if err != nil {
			return nil, err
		}
		if rewardOpt == nil {
			return nil, zhios_order_relate_logx.Warn("找不到方案记录")
		}
		if rewardOpt.State == 0 {
			return nil, zhios_order_relate_logx.Warn("抽成方案未开启")
		}
		if rewardOpt.PlanCommissionId == 0 {
			return nil, zhios_order_relate_logx.Warn("抽成方案未设置佣金方案id")
		}
		fmt.Println("抽成设置:", zhios_order_relate_utils.SerializeStr(rewardOpt))
		fmt.Println("commission id:", rewardOpt.PlanCommissionId)

		//TODO::计算共富收益
		commissionOpt, err := db.DbsPlanCommissionById(engine, rewardOpt.PlanCommissionId)
		if err != nil || commissionOpt == nil || commissionOpt.Id == 0 {
			return nil, err
		}
		var subsidyTmp = make(map[string]*md.LvGrade)
		var tmp map[string]*md.LvGrade
		if err := json.Unmarshal([]byte(commissionOpt.Data), &tmp); err != nil {
			return nil, zhios_order_relate_logx.Warn(fmt.Sprintf("%s:分佣方案数据设置错误", masterId))
		}
		for _, v := range tmp {
			subsidyTmp[zhios_order_relate_utils.IntToStr(v.Lv)] = v
		}
		lvGrade := subsidyTmp[param.UserLevel]
		var directPush = make(map[string]string)
		var selfRateList = make(map[string]string)
		var commonWealthSystem = make(map[string]string)
		for _, coinId := range lvGrade.ReturnType {
			selfRateList[coinId] = zhios_order_relate_utils.Float64ToStr(zhios_order_relate_utils.StrToFloat64(lvGrade.SelfRateList[coinId]) * zhios_order_relate_utils.StrToFloat64(param.PendingAmount) / 100)
			commonWealthSystem[coinId] = zhios_order_relate_utils.Float64ToStr(zhios_order_relate_utils.StrToFloat64(lvGrade.CommonWealthSystem[coinId]) * zhios_order_relate_utils.StrToFloat64(param.PendingAmount) / 100)
			directPush[coinId] = zhios_order_relate_utils.Float64ToStr(zhios_order_relate_utils.StrToFloat64(lvGrade.DirectPush[coinId]) * zhios_order_relate_utils.StrToFloat64(param.PendingAmount) / 100)
		}

		//TODO::本次消费产生的共富收益给到谁
		var nowBenefitUid string
		userPublicPlatoonRelation, err := db.UserSmallPublicPlatoonRelationGetOneByParams(engine, map[string]interface{}{
			"key":   "uid",
			"value": param.Uid,
		})
		if err != nil {
			return nil, err
		}
		if userPublicPlatoonRelation == nil {
			return nil, errors.New("未查询到公排关系记录")
		}
		if userPublicPlatoonRelation.FatherUid == "" {
			//TODO::原始创始人
			nowBenefitUid = ""
		} else {
			fatherPositions := strings.Split(userPublicPlatoonRelation.FatherUid, "-")
			var fatherPosition string
			userPublicPlatoonRelation.ReturnCommissionNum++

			remainder1 := (userPublicPlatoonRelation.ReturnCommissionNum) % len(fatherPositions)
			if remainder1 == 0 {
				fatherPosition = fatherPositions[len(fatherPositions)-1]
			} else {
				fatherPosition = fatherPositions[remainder1-1]
			}

			nowBenefitUsers, err := db.UserSmallPublicPlatoonRelationGetOneByParams(engine, map[string]interface{}{
				"key":   "id",
				"value": fatherPosition,
			})
			if err != nil {
				return nil, err
			}
			if nowBenefitUsers == nil {
				return nil, errors.New("未查询到父级公排关系记录")
			}
			if nowBenefitUsers.Uid == -1 || nowBenefitUsers.Uid == -2 {
				//则为待填充空位用户
				nowBenefitUid = ""
			} else {
				nowBenefitUid = zhios_order_relate_utils.AnyToString(nowBenefitUsers.Uid)
			}

			//TODO::更新 公排关系记录 中 `return_commission_num`
			affected, err := db.UserSmallPublicPlatoonRelationUpdate(engine.NewSession(), userPublicPlatoonRelation.Id, userPublicPlatoonRelation, "return_commission_num")
			if err != nil {
				return nil, err
			}
			if affected == 0 {
				return nil, errors.New("更新公排关系记录失败")
			}
		}

		resp[param.Oid] = &md.SmallPublicPlatoonRelateCommissionResp{
			Uid:                    param.Uid,
			CommonWealthBenefitUid: nowBenefitUid,
			DirectPushBenefitUid:   strconv.Itoa(userPublicPlatoonRelation.RecommendUid),
			PendingAmount:          param.PendingAmount,
			Oid:                    param.Oid,
			SelfRateList:           selfRateList,
			CommonWealthSystem:     commonWealthSystem,
			DirectPush:             directPush,
		}
	}
	return resp, nil
}

func BatchSmallGetPublicPlatoonRelateByGoods(engine *xorm.Engine, masterId string, PublicPlatoonRelateCommissionReqList []*md.SmallPublicPlatoonRelateCommissionReq) (map[string]*md.SmallPublicPlatoonRelateCommissionResp, error) {
	var resp = make(map[string]*md.SmallPublicPlatoonRelateCommissionResp)
	for _, param := range PublicPlatoonRelateCommissionReqList {
		// 根据供应商
		rewardOpt, err := db.DbsPlanRewardByPvd(engine, param.Pvd)
		if err != nil {
			return nil, err
		}
		if rewardOpt == nil {
			return nil, zhios_order_relate_logx.Warn("找不到方案记录")
		}
		if rewardOpt.State == 0 {
			return nil, zhios_order_relate_logx.Warn("抽成方案未开启")
		}
		if rewardOpt.PlanCommissionId == 0 {
			return nil, zhios_order_relate_logx.Warn("抽成方案未设置佣金方案id")
		}
		fmt.Println("抽成设置:", zhios_order_relate_utils.SerializeStr(rewardOpt))
		fmt.Println("commission id:", rewardOpt.PlanCommissionId)

		//TODO::计算共富收益
		commissionOpt, err := db.DbsPlanCommissionById(engine, rewardOpt.PlanCommissionId)
		if err != nil || commissionOpt == nil || commissionOpt.Id == 0 {
			return nil, err
		}
		var subsidyTmp = make(map[string]*md.LvGrade)
		var tmp map[string]*md.LvGrade
		if err := json.Unmarshal([]byte(commissionOpt.Data), &tmp); err != nil {
			return nil, zhios_order_relate_logx.Warn(fmt.Sprintf("%s:分佣方案数据设置错误", masterId))
		}
		for _, v := range tmp {
			subsidyTmp[zhios_order_relate_utils.IntToStr(v.Lv)] = v
		}
		lvGrade := subsidyTmp[param.UserLevel]
		var directPush = make(map[string]string)
		var selfRateList = make(map[string]string)
		var commonWealthSystem = make(map[string]string)
		for _, coinId := range lvGrade.ReturnType {
			selfRateList[coinId] = zhios_order_relate_utils.Float64ToStr(zhios_order_relate_utils.StrToFloat64(lvGrade.SelfRateList[coinId]) * zhios_order_relate_utils.StrToFloat64(param.PendingAmount) / 100)
			commonWealthSystem[coinId] = zhios_order_relate_utils.Float64ToStr(zhios_order_relate_utils.StrToFloat64(lvGrade.CommonWealthSystem[coinId]) * zhios_order_relate_utils.StrToFloat64(param.PendingAmount) / 100)
			directPush[coinId] = zhios_order_relate_utils.Float64ToStr(zhios_order_relate_utils.StrToFloat64(lvGrade.DirectPush[coinId]) * zhios_order_relate_utils.StrToFloat64(param.PendingAmount) / 100)
		}
		resp[param.Oid] = &md.SmallPublicPlatoonRelateCommissionResp{
			PendingAmount:      param.PendingAmount,
			Oid:                param.Oid,
			SelfRateList:       selfRateList,
			CommonWealthSystem: commonWealthSystem,
			DirectPush:         directPush,
		}
	}
	return resp, nil
}
